@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003, 2004 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004, 2005 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -29,7 +29,7 @@ extern "C" {
  * 0.2.6-1 => 0x00020601
  * 4.5.2-0 => 0x04050200
  */
-#define EXTRACTOR_VERSION 0x00031100
+#define EXTRACTOR_VERSION 0x00040200
 
 #include <stdio.h>
 
@@ -40,6 +40,10 @@ extern "C" {
    preserved */
 #define EXTRACTOR_DUPLICATES_REMOVE_UNKNOWN 2
 
+#define EXTRACTOR_DEFAULT_LIBRARIES EXTRACTOR_getDefaultLibraries()
+
+const char * EXTRACTOR_getDefaultLibraries();
+
 /**
  * Enumeration defining various sources of keywords.
  * See also
@@ -115,6 +119,8 @@ typedef enum {
   EXTRACTOR_OWNER = 66,
   EXTRACTOR_LYRICS = 67,
   EXTRACTOR_MEDIA_TYPE = 68,
+  EXTRACTOR_CONTACT = 69,
+  EXTRACTOR_THUMBNAIL_DATA = 70,
 } EXTRACTOR_KeywordType;
 
 /**
