@@ -56,12 +56,6 @@
  #include <pthread.h>
 #endif
 
-
-/**
- * Open a file
- */
-int OPEN(const char *filename, int oflag, ...);
-
 #ifndef MINGW
  #define DIR_SEPARATOR '/'
  
