@@ -23,6 +23,10 @@
 #include "getopt.h"
 
 #include <locale.h>
+#include <iconv.h>
+#ifndef MINGW
+#include <langinfo.h>
+#endif
 
 #define YES 1
 #define NO 0
@@ -164,6 +168,8 @@ printHelp ()
   
 }
 
+#include "iconv.c"
+
 
 /**
  * Print a keyword list to a file.
@@ -173,29 +179,52 @@ printHelp ()
  * @param print array indicating which types to print
  */
 static void
-printSelectedKeywords (FILE * handle,
-		       EXTRACTOR_KeywordList * keywords,
-		       const int * print, 
-		       const int verbose)
+printSelectedKeywords(FILE * handle,
+		      EXTRACTOR_KeywordList * keywords,
+		      const int * print, 
+		      const int verbose)
 {
-  while (keywords != NULL)
-    {
-      if (NULL == EXTRACTOR_getKeywordTypeAsString (keywords->keywordType))
-	{
-	  if (verbose == YES)
-	    {
-	      fprintf (handle, 
-		       "INVALID TYPE - %s\n",
-		       keywords->keyword);
-	    }
+  char * keyword;
+  iconv_t cd;
+  char * buf;
+
+  cd = iconv_open(
+#ifdef MINGW
+    "char"
+#else
+    nl_langinfo(CODESET)
+#endif
+    , "UTF-8");
+  while (keywords != NULL) {
+    buf = NULL;
+    if (cd != (iconv_t) -1)
+      keyword = iconvHelper(cd, 
+			    keywords->keyword);
+    else
+      keyword = strdup(keywords->keyword);
+
+    if (keywords->keywordType == EXTRACTOR_THUMBNAIL_DATA) {
+      fprintf (handle,
+	       _("%s - (binary)\n"),
+	       EXTRACTOR_getKeywordTypeAsString(keywords->keywordType));
+    } else {
+      if (NULL == EXTRACTOR_getKeywordTypeAsString(keywords->keywordType)) {
+	if (verbose == YES) {
+	  fprintf(handle, 
+		  _("INVALID TYPE - %s\n"),
+		  keyword);
 	}
-      else if (print[keywords->keywordType] == YES)
+      } else if (print[keywords->keywordType] == YES)
 	fprintf (handle,
 		 "%s - %s\n",
-		 EXTRACTOR_getKeywordTypeAsString (keywords->keywordType),
-		 keywords->keyword);
-      keywords = keywords->next;
+		 EXTRACTOR_getKeywordTypeAsString(keywords->keywordType),
+		 keyword);
     }
+    free(keyword);
+    keywords = keywords->next;
+  }
+  if (cd != (iconv_t) -1)
+    iconv_close(cd);
 }
 
 /**
