@@ -27,6 +27,10 @@
 #include <../../libltdl/ltdl.h>
 #endif
 #include <locale.h>
+#include <iconv.h>
+#ifndef MINGW
+#include <langinfo.h>
+#endif
 
 #define DEBUG 1
 
@@ -103,11 +107,13 @@ static const char *keywordTypes[] = {
   gettext_noop("owner"),
   gettext_noop("lyrics"),
   gettext_noop("media type"),
+  gettext_noop("contact"),
+  gettext_noop("binary thumbnail data"),
   NULL,
 };
 
 /* the number of keyword types (for bounds-checking) */
-#define HIGHEST_TYPE_NUMBER 69
+#define HIGHEST_TYPE_NUMBER 71
 
 #ifdef HAVE_LIBOGG
 #if HAVE_VORBIS
@@ -169,6 +175,10 @@ libextractor_asf"
 
 #define DEFAULT_LIBRARIES OLESO OGGSO QTSO DEFSO
 
+const char * EXTRACTOR_getDefaultLibraries() {
+  return DEFAULT_LIBRARIES;
+}
+
 /* ************library initialization ***************** */
 
 #ifdef MINGW
@@ -220,6 +230,51 @@ void __attribute__ ((destructor)) le_ltdl_fini(void) {
   lt_dlexit ();
 }
 
+/**
+ * Open a file
+ */
+static int OPEN(const char *filename, 
+		int oflag, ...) {
+  int mode;
+  char *fn;
+
+#ifdef MINGW
+  char szFile[_MAX_PATH + 1];
+  long lRet;
+  
+  if ((lRet = conv_to_win_path(filename, szFile)) != ERROR_SUCCESS)
+  {
+    errno = ENOENT;
+    SetLastError(lRet);
+    
+    return -1;
+  }
+  fn = szFile;
+#else
+  fn = (char *) filename;
+#endif
+  
+  if (oflag & O_CREAT)
+  {
+    va_list arg;
+    va_start(arg, oflag);
+    mode = va_arg(arg, int);
+    va_end(arg);    
+  }
+  else
+  {
+    mode = 0;
+  }
+  
+#ifdef MINGW
+  /* Set binary mode */
+  mode |= O_BINARY;
+#endif
+  
+  return open(fn, oflag, mode);
+}
+
+
 
 /**
  * Load the default set of libraries. The default set of
@@ -666,6 +721,7 @@ EXTRACTOR_removeEmptyKeywords (EXTRACTOR_KeywordList * list)
   return list;
 }
 
+#include "iconv.c"
 
 /**
  * Print a keyword list to a file.
@@ -674,22 +730,46 @@ EXTRACTOR_removeEmptyKeywords (EXTRACTOR_KeywordList * list)
  * @param keywords the list of keywords to print, may be NULL
  */
 void
-EXTRACTOR_printKeywords (FILE * handle, 
-			 EXTRACTOR_KeywordList * keywords)
+EXTRACTOR_printKeywords(FILE * handle, 
+			EXTRACTOR_KeywordList * keywords)
 {
+  iconv_t cd;
+  char * buf;
+
+  cd = iconv_open(
+#ifdef MINGW
+    ""
+#else
+    nl_langinfo(CODESET)
+#endif
+    , "UTF-8");
   while (keywords != NULL)
     {
-      if (keywords->keywordType >= HIGHEST_TYPE_NUMBER)
-	fprintf(handle, 
-		_("INVALID TYPE - %s\n"),
-		keywords->keyword);
+      if (cd == (iconv_t) -1)
+	buf = strdup(keywords->keyword);
       else
+	buf = iconvHelper(cd,
+			  keywords->keyword);
+      if (keywords->keywordType == EXTRACTOR_THUMBNAIL_DATA) {
 	fprintf(handle,
-		"%s - %s\n",
-		gettext(keywordTypes[keywords->keywordType]),
-		keywords->keyword);
+		_("%s - (binary)\n"),
+		gettext(keywordTypes[keywords->keywordType]));
+      } else {   
+	if (keywords->keywordType >= HIGHEST_TYPE_NUMBER)
+	  fprintf(handle, 
+		  _("INVALID TYPE - %s\n"),
+		  buf);
+	else
+	  fprintf(handle,
+		  "%s - %s\n",
+		  gettext(keywordTypes[keywords->keywordType]),
+		  buf);
+      }
+      free(buf);
       keywords = keywords->next;
     }
+  if (cd != (iconv_t) -1)
+    iconv_close(cd);
 }
 
 /**
@@ -979,54 +1059,8 @@ JNIEXPORT jlong JNICALL Java_org_ovmj_libextractor_Extractor_loadPlugin(JNIEnv *
   return ret; 
 }
 
-#endif
 /* #ifdef HAVE_JNI_H */
-
-
-/* ********************* python support ****************** */
-
-#ifdef HAVE_PYTHON_H
-
-#include <Python.h>
-
-static PyObject * EXTRACTOR_PY_loadDefaultLibraries(PyObject * self) {
-  return Py_BuildValue("l",
-		       (long)EXTRACTOR_loadDefaultLibraries());
-}
-
-static PyObject * EXTRACTOR_PY_removeAll(PyObject * self,
-					 PyObject * args) {
-  long libs;
-
-  PyArg_ParseTuple(args, 
-		   "l", 
-		   &libs);
-  EXTRACTOR_removeAll((EXTRACTOR_ExtractorList*)libs);
-  Py_INCREF(Py_None);
-  return Py_None;
-}
-
-static PyObject * EXTRACTOR_PY_getKeywordTypeAsString(PyObject * self,
-						      PyObject * args) {
-  unsigned int type;
-
-  PyArg_ParseTuple(args, 
-		   "i", 
-		   &type); 
-  return Py_BuildValue("s",
-		       EXTRACTOR_getKeywordTypeAsString((EXTRACTOR_KeywordType)type));
-}
-
-static PyMethodDef ExtractorMethods[] = {
-  { "getKeywordTypeAsString", EXTRACTOR_PY_getKeywordTypeAsString,  METH_VARARGS,
-    "Comment." },
-  { NULL, NULL, 0, NULL }
-};
-
-PyMODINIT_FUNC 
-initextractor() {
-  Py_InitModule("extractor", ExtractorMethods);
-}
-
-
 #endif
+
+
+/* end of extractor.c */
