@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2004 Christian Grothoff (and other contributing authors)
+     (C) 2004 - 2005 Christian Grothoff (and other contributing authors)
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -204,6 +204,7 @@ int mkstemp(char *tmplate)
     = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
   int iLen, iRnd;
   char *pChr;
+  char szDest[_MAX_PATH + 1];
 
   iLen = strlen(tmplate);
   if(iLen >= 6)
@@ -232,7 +233,10 @@ int mkstemp(char *tmplate)
     errno = EINVAL;
     return -1;
   }
-  return _open(tmplate, _O_CREAT | _O_EXCL, _S_IREAD | _S_IWRITE);
+
+  conv_to_win_path(tmplate, szDest);
+
+  return _open(szDest, _O_CREAT | _O_EXCL, _S_IREAD | _S_IWRITE);
 }
 
 /*********************** posix path -> win path ****************************/
