@@ -16,7 +16,7 @@
      along with libextractor; see the file COPYING.  If not, write to the
      Free Software Foundation, Inc., 59 Temple Place - Suite 330,
      Boston, MA 02111-1307, USA.
- **/
+ */
 
 /*
  * This file is based on demux_asf from the xine project (copyright follows).
@@ -39,7 +39,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: asfextractor.c,v 1.5 2004/05/31 22:54:31 grothoff Exp $
+ * $Id: asfextractor.c,v 1.6 2004/10/05 20:02:08 grothoff Exp $
  *
  * demultiplexer for asf streams
  *
@@ -51,13 +51,8 @@
  * some other ideas from MPlayer
  */
 
-#include "extractor_util.h"
-
-#include <stdio.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <string.h>
-#include <stdlib.h>
+#include "platform.h"
+#include "extractor.h"
 
 #define CODEC_TYPE_AUDIO       0
 #define CODEC_TYPE_VIDEO       1
