@@ -20,6 +20,11 @@
 
 #include "platform.h"
 #include "extractor.h"
+#include "convert.h"
+#ifndef MINGW
+#include <langinfo.h>
+#endif
+
 
 /* "extract" the 'filename' as a keyword */
 struct EXTRACTOR_Keywords * libextractor_filename_extract(const char * filename,
@@ -37,7 +42,14 @@ struct EXTRACTOR_Keywords * libextractor_filename_extract(const char * filename,
     }
   keyword = malloc(sizeof(EXTRACTOR_KeywordList));
   keyword->next = prev;    
-  keyword->keyword = strdup(filenameRoot);
+  keyword->keyword = convertToUtf8(filenameRoot,
+				   strlen(filenameRoot),
+#ifndef MINGW
+				   nl_langinfo(CODESET)
+#else
+           ""
+#endif
+           );
   keyword->keywordType = EXTRACTOR_FILENAME;
   return keyword;
 }
