@@ -256,36 +256,3 @@ struct EXTRACTOR_Keywords * libextractor_gif_extract(const char * filename,
   return result;  
 }
 
-#define HAVE_MAIN 0
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(argv[1],O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == FSTAT(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_gif_extract(argv[1], 
-						   buffer,
-						   size,
-						   NULL));
-  munmap(buffer, size);
-  return 0;
-}
-#endif
