@@ -19,20 +19,15 @@
 
  */
 
-#define DEBUG_EXTRACT_ID3v2 0
-
 #include "platform.h"
 #include "extractor.h"
-#include <string.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <fcntl.h>
 #ifndef MINGW
   #include <sys/mman.h>
 #endif
+#include "convert.h"
+
+#define DEBUG_EXTRACT_ID3v2 0
+
 
 static struct EXTRACTOR_Keywords * addKeyword(EXTRACTOR_KeywordList *oldhead, 
 					      char *phrase,
@@ -130,16 +125,32 @@ struct EXTRACTOR_Keywords * libextractor_id3v2_extract(char * filename,
 		       &data[pos],
 		       3)) {
 	char * word;
-	word = malloc(csize+1);
-	if (data[pos+6] == '\0') {
-	  pos++;
-	  csize--;
+	/* this byte describes the encoding
+	   try to convert strings to UTF-8
+	   if it fails, then forget it */
+	switch (data[pos+6]) {
+	case 0x00:
+	  word = convertToUtf8(&data[pos+7],
+			       csize,
+			       "ISO-8859-1");
+	  break;
+	case 0x01:
+	  word = convertToUtf8(&data[pos+7],
+			       csize,
+			       "UCS-2");
+	  break;
+	default:
+	  /* bad encoding byte,
+	     try to convert from iso-8859-1 */
+	  word = convertToUtf8(&data[pos+7],
+			       csize,
+			       "ISO-8859-1");
+	  break;
 	}
-	memcpy(word,
-	       &data[pos+6],
-	       csize);
-	word[csize] = '\0';
-	if (strlen(word) > 0) {
+	pos++;
+	csize--;
+	if ( (word != NULL) &&
+	     (strlen(word) > 0) ) {
 	  prev = addKeyword(prev,
 			    word,
 			    tmap[i].type);	
@@ -155,40 +166,4 @@ struct EXTRACTOR_Keywords * libextractor_id3v2_extract(char * filename,
   return prev;
 }
 
-
-#define HAVE_MAIN 0
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(argv[1], O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == FSTAT(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_id3v2_extract(argv[1], 
-						     buffer,
-						     size,
-						     NULL));
-  munmap(buffer, size);
-  return 0;
-}
-#endif
-
-
 /* end of id3v2extractor.c */
