@@ -271,37 +271,3 @@ struct EXTRACTOR_Keywords * libextractor_mime_extract(char * filename,
   return prev;
 }
 
-#define HAVE_MAIN 0
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(filename,O_RDONLY);
-  if (-1 == file) 
-    return NULL;
-  if (-1 == FSTAT(file, &fstatbuf)) {
-    close(file);
-    return NULL;
-  }
-  size = fstatbuf.st_size;
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_mime_extract(argv[1], 
-						    NULL, 
-						    buffer,
-						    size,
-						    NULL));
-  free(size);
-  return 0;
-}
-#endif
