@@ -28,6 +28,7 @@
 
 #include "platform.h"
 #include "extractor.h"
+#include "convert.h"
 #include <string.h>
 #include <stdio.h>
 #include <sys/types.h>
@@ -36,13 +37,168 @@
 #include <stdlib.h>
 
 typedef struct {
-  char title[31];
-  char artist[31];
-  char album[31];
-  char year[5];
-  char comment[31];
+  char * title;
+  char * artist;
+  char * album;
+  char * year;
+  char * comment;
+  char * genre;
 } id3tag;
 
+static const char *const genre_names[] = {
+    gettext_noop("Blues"),
+    gettext_noop("Classic Rock"), 
+    gettext_noop("Country"), 
+    gettext_noop("Dance"), 
+    gettext_noop("Disco"), 
+    gettext_noop("Funk"), 
+    gettext_noop("Grunge"),
+    gettext_noop("Hip-Hop"),
+    gettext_noop("Jazz"), 
+    gettext_noop("Metal"), 
+    gettext_noop("New Age"),
+    gettext_noop("Oldies"),
+    gettext_noop("Other"), 
+    gettext_noop("Pop"), 
+    gettext_noop("R&B"),
+    gettext_noop("Rap"),
+    gettext_noop("Reggae"),
+    gettext_noop("Rock"),
+    gettext_noop("Techno"),
+    gettext_noop("Industrial"),
+    gettext_noop("Alternative"),
+    gettext_noop("Ska"),
+    gettext_noop("Death Metal"), 
+    gettext_noop("Pranks"),
+    gettext_noop("Soundtrack"), 
+    gettext_noop("Euro-Techno"),
+    gettext_noop("Ambient"), 
+    gettext_noop("Trip-Hop"),
+    gettext_noop("Vocal"),
+    gettext_noop("Jazz+Funk"),
+    gettext_noop("Fusion"), 
+    gettext_noop("Trance"), 
+    gettext_noop("Classical"), 
+    gettext_noop("Instrumental"),
+    gettext_noop("Acid"),
+    gettext_noop("House"),
+    gettext_noop("Game"),
+    gettext_noop("Sound Clip"), 
+    gettext_noop("Gospel"),
+    gettext_noop("Noise"), 
+    gettext_noop("Alt. Rock"),
+    gettext_noop("Bass"), 
+    gettext_noop("Soul"), 
+    gettext_noop("Punk"),
+    gettext_noop("Space"),
+    gettext_noop("Meditative"),
+    gettext_noop("Instrumental Pop"),
+    gettext_noop("Instrumental Rock"), 
+    gettext_noop("Ethnic"), 
+    gettext_noop("Gothic"),
+    gettext_noop("Darkwave"), 
+    gettext_noop("Techno-Industrial"),
+    gettext_noop("Electronic"),
+    gettext_noop("Pop-Folk"),
+    gettext_noop("Eurodance"), 
+    gettext_noop("Dream"), 
+    gettext_noop("Southern Rock"),
+    gettext_noop("Comedy"),
+    gettext_noop("Cult"), 
+    gettext_noop("Gangsta Rap"), 
+    gettext_noop("Top 40"), 
+    gettext_noop("Christian Rap"),
+    gettext_noop("Pop/Funk"),
+    gettext_noop("Jungle"),
+    gettext_noop("Native American"),
+    gettext_noop("Cabaret"), 
+    gettext_noop("New Wave"),
+    gettext_noop("Psychedelic"),
+    gettext_noop("Rave"),
+    gettext_noop("Showtunes"), 
+    gettext_noop("Trailer"),
+    gettext_noop("Lo-Fi"), 
+    gettext_noop("Tribal"), 
+    gettext_noop("Acid Punk"),
+    gettext_noop("Acid Jazz"),
+    gettext_noop("Polka"),
+    gettext_noop("Retro"),
+    gettext_noop("Musical"),
+    gettext_noop("Rock & Roll"),
+    gettext_noop("Hard Rock"),
+    gettext_noop("Folk"),
+    gettext_noop("Folk/Rock"),
+    gettext_noop("National Folk"),
+    gettext_noop("Swing"),
+    gettext_noop("Fast-Fusion"), 
+    gettext_noop("Bebob"),
+    gettext_noop("Latin"),
+    gettext_noop("Revival"),
+    gettext_noop("Celtic"),
+    gettext_noop("Bluegrass"),
+    gettext_noop("Avantgarde"), 
+    gettext_noop("Gothic Rock"),
+    gettext_noop("Progressive Rock"), 
+    gettext_noop("Psychedelic Rock"),
+    gettext_noop("Symphonic Rock"), 
+    gettext_noop("Slow Rock"),
+    gettext_noop("Big Band"), 
+    gettext_noop("Chorus"),
+    gettext_noop("Easy Listening"),
+    gettext_noop("Acoustic"), 
+    gettext_noop("Humour"),
+    gettext_noop("Speech"),
+    gettext_noop("Chanson"),
+    gettext_noop("Opera"), 
+    gettext_noop("Chamber Music"),
+    gettext_noop("Sonata"),
+    gettext_noop("Symphony"), 
+    gettext_noop("Booty Bass"),
+    gettext_noop("Primus"), 
+    gettext_noop("Porn Groove"),
+    gettext_noop("Satire"),
+    gettext_noop("Slow Jam"), 
+    gettext_noop("Club"), 
+    gettext_noop("Tango"), 
+    gettext_noop("Samba"),
+    gettext_noop("Folklore"), 
+    gettext_noop("Ballad"), 
+    gettext_noop("Power Ballad"), 
+    gettext_noop("Rhythmic Soul"),
+    gettext_noop("Freestyle"), 
+    gettext_noop("Duet"),
+    gettext_noop("Punk Rock"),
+    gettext_noop("Drum Solo"), 
+    gettext_noop("A Cappella"), 
+    gettext_noop("Euro-House"),
+    gettext_noop("Dance Hall"),
+    gettext_noop("Goa"),
+    gettext_noop("Drum & Bass"),
+    gettext_noop("Club-House"),
+    gettext_noop("Hardcore"), 
+    gettext_noop("Terror"), 
+    gettext_noop("Indie"),
+    gettext_noop("BritPop"),
+    gettext_noop("Negerpunk"),
+    gettext_noop("Polsk Punk"),
+    gettext_noop("Beat"),
+    gettext_noop("Christian Gangsta Rap"),
+    gettext_noop("Heavy Metal"),
+    gettext_noop("Black Metal"),
+    gettext_noop("Crossover"),
+    gettext_noop("Contemporary Christian"),
+    gettext_noop("Christian Rock"), 
+    gettext_noop("Merengue"),
+    gettext_noop("Salsa"),
+    gettext_noop("Thrash Metal"),
+    gettext_noop("Anime"),
+    gettext_noop("JPop"),
+    gettext_noop("Synthpop"),
+};
+
+#define GENRE_NAME_COUNT \
+    ((unsigned int)(sizeof genre_names / sizeof (const char *const)))
+
 
 #define MAX_MP3_SCAN_DEEP 16768
 const int max_frames_scan=1024;
@@ -98,24 +254,9 @@ static char * unpad(char * string) {
   return string;
 }
 
-/**
- * Copy a string from src to dst and unpad.
- */
-static void copypad(char * dst,
-		    char * src,
-		    int len) {
-  memcpy(dst, src, len);
-  dst[len] = '\0';
-  unpad(dst);
-}
-
-/**
- * Copy from b to a len characters and advance
- * b by len.
- */
-#define COPYPADADV(a,b,c) copypad(a,b,c); b+=c;
-
-static int get_id3(char * data, size_t size, id3tag * id3) {
+static int get_id3(unsigned char * data,
+		   size_t size,
+		   id3tag * id3) {
   char * pos;
 
   if (size < 128)
@@ -125,11 +266,25 @@ static int get_id3(char * data, size_t size, id3tag * id3) {
   if (0 != strncmp((const char *)"TAG",(const char *)pos, 3))
     return INVALID_ID3;      
   pos += 3;
-  COPYPADADV(id3->title, pos, 30);
-  COPYPADADV(id3->artist, pos, 30); 
-  COPYPADADV(id3->album, pos, 30);
-  COPYPADADV(id3->year, pos, 4);
-  COPYPADADV(id3->comment, pos, 30);
+
+  id3->title = convertToUtf8(pos,
+			     30,
+			     "ISO-8859-1"); pos += 30;
+  id3->artist = convertToUtf8(pos,
+			      30,
+			      "ISO-8859-1"); pos += 30;
+  id3->album = convertToUtf8(pos,
+			      30,
+			      "ISO-8859-1"); pos += 30;
+  id3->year = convertToUtf8(pos,
+			    4,
+			    "ISO-8859-1"); pos += 4;
+  id3->comment = convertToUtf8(pos,
+			       30,
+			       "ISO-8859-1"); pos += 30;
+  id3->genre = "";
+  if (pos[0] < GENRE_NAME_COUNT)
+    id3->genre = dgettext(PACKAGE, genre_names[pos[0]]);
   return OK;
 }
 
@@ -299,14 +454,8 @@ libextractor_mp3_extract(char * filename,
   id3tag info;
   char * word;
 
-  if (0 != get_id3(data, size, &info)) {
-#if DEBUG_EXTRACT_MP3
-    fprintf(stderr, 
-	    "\nIgnoring %s (could not decode id3 header)\n",
-	    filename);
-#endif
+  if (0 != get_id3(data, size, &info)) 
     return klist;
-  }
 
   if (strlen(info.title) > 0) 
     klist = addkword(klist, info.title, EXTRACTOR_TITLE); 
@@ -316,6 +465,10 @@ libextractor_mp3_extract(char * filename,
     klist = addkword(klist, info.album, EXTRACTOR_ALBUM);
   if (strlen(info.year) > 0) 
     klist = addkword(klist, info.year, EXTRACTOR_DATE);
+  if (strlen(info.genre) > 0) 
+    klist = addkword(klist, info.genre, EXTRACTOR_GENRE);
+  if (strlen(info.genre) > 0) 
+    klist = addkword(klist, info.comment, EXTRACTOR_COMMENT);
 
 
   /* A keyword that has all of the information together) */
@@ -327,6 +480,11 @@ libextractor_mp3_extract(char * filename,
 	  info.album);
   klist = addkword(klist, word, EXTRACTOR_DESCRIPTION);
   free(word);
+  free(info.title);
+  free(info.year);
+  free(info.album);
+  free(info.artist);
+  free(info.comment);
 
   return mp3parse(data,
 		  size,
