@@ -1,6 +1,7 @@
+
 /*
      This file is part of libextractor.
-     (C) 2004 Vidyut Samanta and Christian Grothoff
+     (C) 2004, 2005 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -30,8 +31,6 @@
 #include "extractor.h"
 #include "pack.h"
 
-#define HAVE_MAIN 0
-
 static void addKeyword(struct EXTRACTOR_Keywords ** list,
 		       char * keyword,
 		       EXTRACTOR_KeywordType type) {
@@ -173,38 +172,3 @@ struct EXTRACTOR_Keywords * libextractor_mpeg_extract(char * filename,
   return prev;
 }
 
-
-
-
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(argv[1],O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == fstat(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_mpeg_extract(argv[1], 
-						    buffer,
-						    size,
-						    NULL));
-  munmap(buffer,size);
-  return 0;
-}
-#endif
