@@ -73,7 +73,7 @@ static long tellError(void * datasource) {
   return -1;
 }
 
-/* mimetype = audio/ogg */
+/* mimetype = application/ogg */
 struct EXTRACTOR_Keywords * libextractor_ogg_extract(char * filename,
                                                      char * data,
                                                      size_t size,
@@ -116,7 +116,9 @@ struct EXTRACTOR_Keywords * libextractor_ogg_extract(char * filename,
 
   prev = addKeyword(EXTRACTOR_TITLE, get_comment(comments, "title"), prev);
   prev = addKeyword(EXTRACTOR_ARTIST, get_comment(comments, "artist"), prev);
+  prev = addKeyword(EXTRACTOR_INTERPRET, get_comment(comments, "performer"), prev);
   prev = addKeyword(EXTRACTOR_ALBUM, get_comment(comments, "album"), prev);
+  prev = addKeyword(EXTRACTOR_CONTACT, get_comment(comments, "contact"), prev);
   prev = addKeyword(EXTRACTOR_GENRE, get_comment(comments, "genre"), prev);
   prev = addKeyword(EXTRACTOR_DATE, get_comment(comments, "date"), prev);
   prev = addKeyword(EXTRACTOR_COMMENT, get_comment(comments, ""), prev);
@@ -129,7 +131,7 @@ struct EXTRACTOR_Keywords * libextractor_ogg_extract(char * filename,
   /* we have determined for sure that this is an 
      ogg-vorbis stream, we should add this as a keyword, too */
   prev = addKeyword(EXTRACTOR_MIMETYPE, 
-		    "audio/ogg", 
+		    "application/ogg", 
 		    prev);
   /* build a description from artist, title and album */
   {
