@@ -24,7 +24,7 @@
 
 #include "platform.h"
 #include "extractor.h"
-
+#include "../convert.h"
 #include <math.h>
 
 #include "parseargs.h"
@@ -64,29 +64,40 @@ extern "C" {
 						     EXTRACTOR_KeywordType type,
 						     struct EXTRACTOR_Keywords * next) {
     Object obj;
-    GString *s1, *s2;
-    int i;
+    GString *s1;
+    char * s;
     
     if (infoDict->lookup(key, &obj)->isString()) {
       s1 = obj.getString();
-      if ((s1->getChar(0) & 0xff) == 0xfe &&
-	  (s1->getChar(1) & 0xff) == 0xff) {
-	s2 = new GString();
-	for (i = 2; i < obj.getString()->getLength(); i += 2) {
-	  if (s1->getChar(i) == '\0') {
-	    s2->append(s1->getChar(i+1));
-	  } else {
-	    delete s2;
-	    s2 = new GString("<unicode>");
-	    break;
-	  }
-	}
-	next = addKeyword(type, strdup(s2->getCString()), next);
-	/* printf(fmt, s2->getCString());*/
-	delete s2;
+      s = s1->getCString();
+      if ((((unsigned char)s[0]) & 0xff) == 0xfe &&
+	  (((unsigned char)s[1]) & 0xff) == 0xff) {
+	char * result;
+	unsigned char u[2];
+	unsigned int pos;
+	unsigned int len;
+	char * con;
+
+	result = (char*) malloc(s1->getLength() * 4);
+	result[0] = '\0';
+	len = s1->getLength();
+	for (pos=0;pos<len;pos+=2) {
+	  u[0] = s1->getChar(pos+1);
+	  u[1] = s1->getChar(pos);
+	  con = (char*) convertToUtf8((const char*) u, 2, "UNICODE");
+	  strcat(result, con);
+	  free(con);
+	}		       
+	next = addKeyword(type,
+			  strdup(result),
+			  next);
+	free(result);
       } else {
-	next = addKeyword(type, strdup(s1->getCString()), next);
-	/* printf(fmt, s1->getCString());*/
+	next = addKeyword(type, 
+			  convertToUtf8(s,
+					strlen(s),
+					"ISO-8859-1"),
+			  next);
       }
     }
     obj.free();
@@ -99,13 +110,41 @@ extern "C" {
 						   struct EXTRACTOR_Keywords * next) {
     Object obj;
     char *s;
-    
+    GString *s1;
+
     if (infoDict->lookup(key, &obj)->isString()) {
-      s = obj.getString()->getCString();
-      if (s[0] == 'D' && s[1] == ':') {
-	s += 2;
+      s1 = obj.getString();
+      s = s1->getCString();
+
+      if ((s1->getChar(0) & 0xff) == 0xfe &&
+	  (s1->getChar(1) & 0xff) == 0xff) {
+	/* isUnicode */
+	char * result;
+	unsigned char u[2];
+	unsigned int pos;
+	unsigned int len;
+	char * con;
+
+	result = (char*) malloc(s1->getLength() * 4);
+	result[0] = '\0';
+	len = s1->getLength();
+	for (pos=0;pos<len;pos+=2) {
+	  u[0] = s1->getChar(pos+1);
+	  u[1] = s1->getChar(pos);
+	  con = (char*) convertToUtf8((const char*) u, 2, "UNICODE");
+	  strcat(result, con);
+	  free(con);
+	}		       
+	next = addKeyword(type,
+			  strdup(result),
+			  next);
+	free(result);
+      } else {
+	if (s[0] == 'D' && s[1] == ':') {
+	  s += 2;
+	}
+	next = addKeyword(type, strdup(s), next);
       }
-      next = addKeyword(type, strdup(s), next);
       /* printf(fmt, s);*/
     }
     obj.free();
@@ -176,6 +215,7 @@ extern "C" {
       while (blacklist[j] != NULL) {
 	if (0 == strcmp(blacklist[j], mime))
 	  return prev;
+
 	j++;
       }
     }  
@@ -226,6 +266,13 @@ extern "C" {
 			    strdup(pcnt),
 			    result);
       }
+      {
+	char pcnt[20];
+	sprintf(pcnt, "PDF %.1f", doc->getPDFVersion());
+	result = addKeyword(EXTRACTOR_FORMAT,
+			    strdup(pcnt),
+			    result);
+      }
       result = printInfoDate(info.getDict(),   
 			     "CreationDate", 
 			     EXTRACTOR_CREATION_DATE,
@@ -235,6 +282,7 @@ extern "C" {
 			     EXTRACTOR_MODIFICATION_DATE,
 			     result);
     }
+
     info.free();
     delete doc;
     freeParams();
@@ -242,37 +290,3 @@ extern "C" {
     return result;  
   }
 }
-
-#define HAVE_MAIN 0
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = open(argv[1],O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == fstat(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-  buffer = (char*) mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_pdf_extract(argv[1], 
-						   (unsigned char*) buffer,
-						   size,
-						   NULL));
-  munmap(buffer,size);
-  return 0;
-}
-#endif
