@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004, 2005 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -20,6 +20,8 @@
 
 #include "platform.h"
 #include "extractor.h"
+#include <zlib.h>
+#include "convert.h"
 
 static char * stndup(const char * str,
 		     size_t n) {
@@ -44,7 +46,7 @@ static struct EXTRACTOR_Keywords * addKeyword(EXTRACTOR_KeywordType type,
   return result;
 }
 
-static int getIntAt(char * pos) {
+static int getIntAt(const char * pos) {
   char p[4];
 
   memcpy(p, pos, 4); /* ensure alignment! */
@@ -67,10 +69,10 @@ static struct {
    { "Disclaimer", EXTRACTOR_DISCLAIMER},
    { "Warning", EXTRACTOR_WARNING},
    { "Signature", EXTRACTOR_RESOURCE_IDENTIFIER}, 
-   {NULL, EXTRACTOR_UNKNOWN},
+   { NULL, EXTRACTOR_UNKNOWN},
 };
 
-static struct EXTRACTOR_Keywords * processtEXt(unsigned char * data,
+static struct EXTRACTOR_Keywords * processtEXt(const unsigned char * data,
 					       unsigned int length,
 					       struct EXTRACTOR_Keywords * prev) {
   char * keyword;
@@ -81,7 +83,9 @@ static struct EXTRACTOR_Keywords * processtEXt(unsigned char * data,
   off = strnlen(data, length) + 1;
   if (off >= length)
     return prev; /* failed to find '\0' */
-  keyword = stndup(&data[off], length-off);
+  keyword = convertToUtf8(&data[off], 
+			  length-off,
+			  "ISO-8859-1");
   i = 0;
   while (tagmap[i].name != NULL) {
     if (0 == strcmp(tagmap[i].name, data))
@@ -96,43 +100,80 @@ static struct EXTRACTOR_Keywords * processtEXt(unsigned char * data,
 		    prev);
 }
 
-static struct EXTRACTOR_Keywords * processiTXt(unsigned char * data,
+static struct EXTRACTOR_Keywords * processiTXt(const unsigned char * data,
 					       unsigned int length,
 					       struct EXTRACTOR_Keywords * prev) {
   unsigned int pos;
   char * keyword;
-  char * language;
-  char * translated;
+  const char * language;
+  const char * translated;
   int i;
+  int compressed;
+  char * buf;
+  uLongf bufLen;
+  int ret;  
 
-  pos = strnlen(data, length) + 3;
-  if (pos >= length)
+  pos = strnlen(data, length)+1;
+  if (pos+3 >= length)
     return prev;
+  compressed = data[pos++];
+  if (compressed && (data[pos++] != 0))
+    return prev; /* bad compression method */
   language = &data[pos];
-  if (strlen(language) > 0)
+  if (strnlen(language, length-pos) > 0)
     prev = addKeyword(EXTRACTOR_LANGUAGE,
 		      stndup(language, length-pos),
 		      prev);
   pos += strnlen(language, length-pos)+1;
-  if (pos >= length)
+  if (pos+1 >= length)
     return prev;
-  translated = &data[pos];
-  if (strlen(translated) > 0)
+  translated = &data[pos]; /* already in utf-8! */
+  if (strnlen(translated, length-pos) > 0)
     prev = addKeyword(EXTRACTOR_TRANSLATED,
 		      stndup(translated, length-pos),
 		      prev);
   pos += strnlen(translated, length-pos)+1;
   if (pos >= length)
     return prev;
-
-  keyword = stndup(&data[pos], length - pos);
   
+  if (compressed) {
+    bufLen = 1024 + 2 * (length - pos);
+    while (1) {
+      if (bufLen * 2 < bufLen)
+	return prev;
+      bufLen *= 2;
+      if (bufLen > 50 * (length - pos)) {
+	/* printf("zlib problem"); */
+	return prev;
+      }
+      buf = malloc(bufLen);
+      if (buf == NULL) {
+	/* printf("out of memory"); */
+	return prev; /* out of memory */
+      }
+      ret = uncompress(buf,
+		       &bufLen,
+		       &data[pos],
+		       length - pos);
+      if (ret == Z_OK) {
+	/* printf("zlib ok"); */
+	break;
+      }
+      free(buf);
+      if (ret != Z_BUF_ERROR)
+	return prev; /* unknown error, abort */
+    }
+    keyword = stndup(buf, bufLen);
+    free(buf);
+  } else {
+    keyword = stndup(&data[pos], length - pos);
+  }  
   i = 0;
   while (tagmap[i].name != NULL) {
     if (0 == strcmp(tagmap[i].name, 
 		    data))
       return addKeyword(tagmap[i].type,
-			keyword,
+			keyword, /* already in utf-8 */
 			prev);
     i++;
   }
@@ -141,7 +182,7 @@ static struct EXTRACTOR_Keywords * processiTXt(unsigned char * data,
 		    prev);
 }
 
-static struct EXTRACTOR_Keywords * processIHDR(unsigned char * data,
+static struct EXTRACTOR_Keywords * processIHDR(const unsigned char * data,
 					       unsigned int length,
 					       struct EXTRACTOR_Keywords * prev) {
   char * tmp;
@@ -161,10 +202,66 @@ static struct EXTRACTOR_Keywords * processIHDR(unsigned char * data,
 }
 
 /* not supported... */
-static struct EXTRACTOR_Keywords * processzTXt(unsigned char * data,
+static struct EXTRACTOR_Keywords * processzTXt(const unsigned char * data,
 					       unsigned int length,
 					       struct EXTRACTOR_Keywords * prev) {
-  return prev;
+  char * keyword;
+  unsigned int off;
+  int i;
+  char * buf;
+  uLongf bufLen;
+  int ret;
+
+  data += 4;
+  off = strnlen(data, length) + 1;
+  if (off >= length)
+    return prev; /* failed to find '\0' */
+  if (data[off] != 0)
+    return prev; /* compression method must be 0 */
+  off++;
+
+  bufLen = 1024 + 2 * (length - off);
+  while (1) {
+    if (bufLen * 2 < bufLen)
+      return prev;
+    bufLen *= 2;
+    if (bufLen > 50 * (length - off)) {
+      /* printf("zlib problem"); */
+      return prev;
+    }
+    buf = malloc(bufLen);
+    if (buf == NULL) {
+      /* printf("out of memory"); */
+      return prev; /* out of memory */
+    }
+    ret = uncompress(buf,
+		     &bufLen,
+		     &data[off],
+		     length - off);
+    if (ret == Z_OK) {
+      /* printf("zlib ok"); */
+      break;
+    }
+    free(buf);
+    if (ret != Z_BUF_ERROR)
+      return prev; /* unknown error, abort */
+  }
+  keyword = convertToUtf8(buf,
+			  bufLen,
+			  "ISO-8859-1");
+  free(buf);
+  i = 0;
+  while (tagmap[i].name != NULL) {
+    if (0 == strcmp(tagmap[i].name, data))
+      return addKeyword(tagmap[i].type,
+			keyword,
+			prev);
+
+    i++;
+  }
+  return addKeyword(EXTRACTOR_UNKNOWN,
+		    keyword,
+		    prev);
 }
 
 #define PNG_HEADER "\211PNG\r\n\032\n"
@@ -172,11 +269,11 @@ static struct EXTRACTOR_Keywords * processzTXt(unsigned char * data,
 
 
 struct EXTRACTOR_Keywords * libextractor_png_extract(char * filename,
-                                                     unsigned char * data,
+                                                     const unsigned char * data,
                                                      size_t size,
                                                      struct EXTRACTOR_Keywords * prev) {
-  unsigned char * pos;
-  unsigned char * end;
+  const unsigned char * pos;
+  const unsigned char * end;
   struct EXTRACTOR_Keywords * result;
   unsigned int length;
 
@@ -193,9 +290,12 @@ struct EXTRACTOR_Keywords * libextractor_png_extract(char * filename,
   while(1) {
     if (pos+12 >= end)
       break;
-    length = htonl(getIntAt(pos));  pos+=4;    
-    if (pos+4+length+4 > end)
+    length = htonl(getIntAt(pos));  pos+=4;
+    /* printf("Length: %u, pos %u\n", length, pos - data); */
+    if ( (pos+4+length+4 > end) ||
+	 (pos+4+length+4 < pos + 4 + length) ) 
       break;
+    
     if (0 == strncmp(pos, "IHDR", 4))
       result = processIHDR(pos, length, result);
     if (0 == strncmp(pos, "iTXt", 4)) 
@@ -209,36 +309,3 @@ struct EXTRACTOR_Keywords * libextractor_png_extract(char * filename,
   return result;  
 }
 
-#define HAVE_MAIN 0
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(argv[1],O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == FSTAT(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_png_extract(argv[1], 
-						   buffer,
-						   size,
-						   NULL));
-  munmap(buffer,size);
-  return 0;
-}
-#endif
