@@ -1,12 +1,8 @@
 /**
  * Tool to build a bloomfilter from a dictionary.
- **/
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
+ */
 
+#include "platform.h"
 #include "bloomfilter.h"
 
 #include "sha1.c"
@@ -29,8 +25,9 @@ int main(int argc,
 #define ALLOCSIZE 1024*1024
   
   if (argc<2) {
-    fprintf(stderr, "please provide the name of the language you are building\n"
-                    "a dictionary for.  For example:\n");
+    fprintf(stderr, 
+	    _("Please provide the name of the language you are building\n"
+	      "a dictionary for.  For example:\n"));
     fprintf(stderr, "$ ./dictionary-builder en > en.c\n");
     exit(-1);
   }
@@ -41,14 +38,17 @@ int main(int argc,
   dictin=fopen(fn,"r");
   free(fn);
   if (dictin==NULL) {
-    fprintf(stderr, "error opening %s: %s\n",
-                    argv[1],strerror(errno));
+    fprintf(stderr, 
+	    _("Error opening file '%s': %s\n"),
+	    argv[1],strerror(errno));
     exit(-1);
   }
   
   words = malloc(sizeof(char*) * ALLOCSIZE); /* don't we LOVE constant size buffers? */
   if (words == NULL) {
-    fprintf(stderr, "out of memory\n.");
+    fprintf(stderr, 
+	    _("Error allocating: %s\n."),
+	    strerror(errno));
     exit(-1);
   }
   cnt = 0;
@@ -58,7 +58,9 @@ int main(int argc,
     cnt++;
     memset(&line[0], 0, 2048);
     if (cnt > ALLOCSIZE) {
-      fprintf(stderr, "increase ALLOCSIZE\n");
+      fprintf(stderr, 
+	      _("Increase ALLOCSIZE (in %s).\n"),
+	      __FILE__);
       exit(-1);
     }
       
