@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -367,6 +367,9 @@ static char * blacklist[] = {
   "application/x-zip",
   "application/x-arj",
   "application/x-compress",
+  "application/x-executable",
+  "application/x-sharedlib",
+  "application/x-archive",
   "application/x-tar",
   "application/x-lha",
   "application/x-gtar",
