@@ -30,8 +30,6 @@
 #include "extractor.h"
 #include <math.h>
 
-#define HAVE_MAIN 0
-
 static void addKeyword(struct EXTRACTOR_Keywords ** list,
 		       char * keyword,
 		       EXTRACTOR_KeywordType type) {
@@ -188,48 +186,3 @@ struct EXTRACTOR_Keywords * libextractor_riff_extract(char * filename,
   return prev;
 }
 
-
-
-
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(argv[1],O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == fstat(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-#ifndef MINGW
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);
-#else
-    buffer = malloc(size + 1);
-    buffer[size + 1] = 0;
-    read(file, buffer, size);
-#endif
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_riff_extract(argv[1], 
-						    buffer,
-						    size,
-						    NULL));
-#ifndef MINGW
-  munmap(buffer,size);
-#else
-  free(buffer);
-#endif
-  return 0;
-}
-#endif
