@@ -74,6 +74,7 @@ static char * DIRECTORY_ENTRY_SPECS[] = {
 #define TAG_ARTIST 0x315
 #define TAG_COPYRIGHT 0x8298
 #define TAG_DESCRIPTION 0x10E
+#define TAG_DOCUMENT_NAME 0x10D
 #define TAG_HOST 0x13C
 #define TAG_SCANNER 0x110
 #define TAG_ORIENTATION 0x112
@@ -212,6 +213,12 @@ struct EXTRACTOR_Keywords * libextractor_tiff_extract(char * filename,
 		 &entry,
 		 EXTRACTOR_ARTIST);
 	break;
+      case TAG_DOCUMENT_NAME:
+	addASCII(&prev,
+		 data, size,
+		 &entry,
+		 EXTRACTOR_TITLE);
+	break;
       case TAG_COPYRIGHT:
 	addASCII(&prev,
 		 data, size,
@@ -254,38 +261,3 @@ struct EXTRACTOR_Keywords * libextractor_tiff_extract(char * filename,
   return prev;
 }
 
-
-
-#define HAVE_MAIN 0
-#if HAVE_MAIN
-int main (int argc, char **argv) {
-  int file;
-  char * buffer;
-  struct stat fstatbuf;
-  size_t size;
-
-  if (argc != 2) {
-    fprintf(stderr, 
-	    "Call with filename as argument\n");
-    return -1;
-  }  
-  file = OPEN(argv[1],O_RDONLY);
-  if (-1 == file) 
-    return -1;
-  if (-1 == fstat(file, &fstatbuf)) {
-    close(file);
-    return -1;
-  }
-  size = fstatbuf.st_size;
-  buffer = mmap(NULL, size, PROT_READ, MAP_SHARED, file, 0);  
-  close(file);
-
-  EXTRACTOR_printKeywords(stdout,
-			  libextractor_tiff_extract(argv[1], 
-						    buffer,
-						    size,
-						    NULL));
-  munmap(buffer,size);
-  return 0;
-}
-#endif
