@@ -3,8 +3,9 @@
  * @brief testcase for libextractor plugin loading that loads the same
  *    plugins multiple times!
  * @author Christian Grothoff
- **/
+ */
 
+#include "platform.h"
 #include "extractor.h"
 
 static int testLoadPlugins() {
