@@ -2,8 +2,8 @@
  * @file test/trivialtest.c
  * @brief trivial testcase for libextractor plugin loading
  * @author Christian Grothoff
- **/
-
+ */
+#include "platform.h"
 #include "extractor.h"
 
 static int testLoadPlugins() {
